import { DifficultyLevel, ReviewStatus } from './education';

// Game Types
export interface GameState {
  score: number;
  finalScore: number;
  isGameOver: boolean;
  isScoreAnimating: boolean;
  selectedCharacter: string;
}

// Character Types
export interface BaseCharacter {
  color: string;
  accentColor: string;
  eyeColor: string;
  shape: 'round' | 'diamond' | 'square' | 'oval';
  size: {
    width: number;
    height: number;
  };
  physics: {
    gravity: number;
    jumpForce: number;
  };
}

// Game Config Types
export interface GameConfig {
  canvas: HTMLCanvasElement;
  container: HTMLDivElement;
  scoreElement: HTMLElement | null;
  gameOverElement: HTMLElement | null;
  finalScoreElement: HTMLElement | null;
}

// Observer Types
export interface GameObservers {
  scoreObserver: MutationObserver;
  gameOverObserver: MutationObserver;
}

// Game Mechanics Types
export interface GameMechanics {
  gravity: number;
  jumpForce: number;
  gameSpeed: number;
  maxVelocityY: number;
}

// Educational Content Types
export interface Subject {
  id: string;
  name: string;
  description: string;
  ageRanges: string[];
  difficulty: 'Beginner' | 'Intermediate' | 'Advanced';
  order?: number;
  isActive?: boolean;
  category?: string;
  gradeLevel?: string[];
  createdAt?: Date;
  updatedAt?: Date;
}

// Base interface for timestamps and status
interface BaseModel {
  id: string;
  createdAt: Date;
  updatedAt: Date;
  isActive: boolean;
}

export interface Question extends BaseModel {
  text: string;
  type: string;
  options: unknown[];
  correctAnswer: unknown;
  explanation: string;
  difficulty: DifficultyLevel;
  bloomsTaxonomyLevel: string;
  topicId: string;
  subjectId: string;
  metadata: Record<string, unknown>;
  points?: number;
  timeLimit?: number;
  ageRange?: string;
  reviewStatus?: ReviewStatus;
}

export interface GameProgress {
  score: number;
  questionsAnswered: number;
  correctAnswers: number;
  timeSpent: number;
  subjectId: string;
} 